@@ -1,7 +1,7 @@
 # -*- coding:utf-8 -*-
 # /usr/bin/env python
 """
-Date: 2020/10/18 16:36
+Date: 2021/6/1 16:36
 Desc: 金十数据-其他-加密货币实时行情
 """
 import time
@@ -34,12 +34,12 @@ def crypto_js_spot() -> pd.DataFrame:
     return data_df
 
 
-def macro_fx_sentiment(start_date: str = "2020-04-22", end_date: str = "2020-04-22") -> pd.DataFrame:
+def macro_fx_sentiment(start_date: str = "20200422", end_date: str = "20200422") -> pd.DataFrame:
     """
     金十数据-外汇-投机情绪报告
     外汇投机情绪报告显示当前市场多空仓位比例，数据由8家交易平台提供，涵盖11个主要货币对和1个黄金品种。
     报告内容: 品种: 澳元兑日元、澳元兑美元、欧元兑美元、欧元兑澳元、欧元兑日元、英镑兑美元、英镑兑日元、纽元兑美元、美元兑加元、美元兑瑞郎、美元兑日元以及现货黄金兑美元。
-             数据: 由Shark - fx整合全球8家交易平台（ 包括Oanda、 FXCM、 Insta、 Dukas、 MyFxBook以及FiboGroup） 的多空投机仓位数据而成。
+             数据: 由Shark - fx整合全球8家交易平台（ 包括 Oanda、 FXCM、 Insta、 Dukas、 MyFxBook以及FiboGroup） 的多空投机仓位数据而成。
     名词释义: 外汇投机情绪报告显示当前市场多空仓位比例，数据由8家交易平台提供，涵盖11个主要货币对和1个黄金品种。
     工具使用策略: Shark-fx声明表示，基于“主流通常都是错误的”的事实，当空头头寸超过60%，交易者就应该建立多头仓位； 同理，当市场多头头寸超过60%，交易者则应该建立空头仓位。此外，当多空仓位比例接近50%的情况下，我们则倾向于建议交易者不要进场，保持观望。
     https://datacenter.jin10.com/reportType/dc_ssi_trends
@@ -50,6 +50,8 @@ def macro_fx_sentiment(start_date: str = "2020-04-22", end_date: str = "2020-04-
     :return: 投机情绪报告
     :rtype: pandas.DataFrame
     """
+    start_date = '-'.join([start_date[:4], start_date[4:6], start_date[6:]])
+    end_date = '-'.join([end_date[:4], end_date[4:6], end_date[6:]])
     url = "https://datacenter-api.jin10.com/sentiment/datas"
     params = {
         "start_date": start_date,
@@ -76,7 +78,7 @@ def macro_fx_sentiment(start_date: str = "2020-04-22", end_date: str = "2020-04-
     return pd.DataFrame(res.json()["data"]["values"]).T
 
 
-def index_vix(start_date: str = "2020-10-15", end_date: str = "2020-10-15") -> pd.DataFrame:
+def index_vix(start_date: str = "20210401", end_date: str = "20210402") -> pd.DataFrame:
     """
     金十数据-市场异动-恐慌指数; 只能获取当前交易日近一个月内的数据
     https://datacenter.jin10.com/market
@@ -88,6 +90,8 @@ def index_vix(start_date: str = "2020-10-15", end_date: str = "2020-10-15") -> p
     :rtype: pandas.DataFrame
     """
     url = "https://datacenter-api.jin10.com/vix/datas"
+    start_date = '-'.join([start_date[:4], start_date[4:6], start_date[6:]])
+    end_date = '-'.join([end_date[:4], end_date[4:6], end_date[6:]])
     params = {
         "start_date": start_date,
         "end_date": end_date,
@@ -118,7 +122,7 @@ if __name__ == "__main__":
     crypto_js_spot_df = crypto_js_spot()
     print(crypto_js_spot_df)
 
-    test_date = datetime.now().date().isoformat()
+    test_date = datetime.now().date().isoformat().replace("-", "")
 
     macro_fx_sentiment_df = macro_fx_sentiment(start_date=test_date, end_date=test_date)
     print(macro_fx_sentiment_df)
