@@ -10,22 +10,7 @@ import os
 import pickle
 import re
 
-# hf_sina_spot
-hf_subscribe_exchange_symbol_url = "http://finance.sina.com.cn/money/future/hf.html"
-hf_subscribe_url = "http://hq.sinajs.cn/"
-hf_subscribe_headers = {
-    "Accept": "*/*",
-    "Accept-Encoding": "gzip, deflate",
-    "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
-    "Cache-Control": "no-cache",
-    "Connection": "keep-alive",
-    "Host": "hq.sinajs.cn",
-    "Pragma": "no-cache",
-    "Referer": "http://finance.sina.com.cn/money/future/hf.html",
-    "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.97 Safari/537.36",
-}
-
-hf_sina_spot_headers = {
+hq_sina_spot_headers = {
     "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3",
     "Accept-Encoding": "gzip, deflate",
     "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
@@ -176,6 +161,7 @@ market_exchange_symbols = {
         "UR",
         "CJ",  # 红枣期货
         "SA",  # 纯碱期货
+        "PK",  # 20210201 花生期货
     ],
     "shfe": [
         "CU",
