@@ -29,28 +29,31 @@ def futures_inventory_em(exchange: str = "上海期货交易所", symbol: str =
     temp_key = [item.text for item in temp_soup]
     temp_value = [item.get("value") for item in temp_soup]
     exchange_dict = dict(zip(temp_key, temp_value))
-
-    temp_text = str(soup.find_all("script", attrs={"type": "text/javascript"})[8])
-    temp_dict = demjson.decode(temp_text[temp_text.find('cv= ')+4:temp_text.rfind(';\r\n;')])
-    temp_item = [item.get("data") for item in temp_dict if item.get("value") == exchange_dict[exchange]][0]
-    symbol_dict = {item[1]: item[0] for item in temp_item}
-
+    url = 'http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx'
+    params = {
+        'type': 'QHKC',
+        'sty': 'QHKCSX',
+        '_': '1618311930407',
+    }
+    r = requests.get(url, params=params)
+    data_text = r.text
+    data_json = demjson.decode(data_text[1:-1])
+    temp_df = pd.DataFrame(data_json)
+    temp_df = temp_df.iloc[:, 0].str.split(',', expand=True)
+    symbol_dict = dict(zip(temp_df.iloc[:, 3], temp_df.iloc[:, 2]))
     url = "http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
     params = {
         "type": "QHKC",
         "sty": "QHKCMX",
         "mkt": exchange_dict[exchange],
         "code": symbol_dict[symbol],
-        "p": "1",
-        "ps": "50",
-        "js": "window.ret={pages:(pc),data:[(x)]}",
+        "stat": "1",
         "_": "1587887394138",
     }
     r = requests.get(url, params=params)
     data_text = r.text
-
-    data_json = demjson.decode(data_text[data_text.find("{"):])
-    temp_df = pd.DataFrame(data_json["data"]).iloc[:, 0].str.split(",", expand=True)
+    data_json = demjson.decode(data_text[1:-1])
+    temp_df = pd.DataFrame(data_json).iloc[:, 0].str.split(",", expand=True)
     temp_df.columns = ["日期", "库存", "增减"]
     return temp_df
 
