@@ -2,7 +2,7 @@
 # /usr/bin/env python
 """
 Date: 2020/4/21 15:34
-Desc: 高频数据-标普500指数
+Desc: 高频数据-标普 500 指数
 https://github.com/FutureSharks/financial-data
 long history data for S&P 500 index daily
 http://www.econ.yale.edu/~shiller/data.htm
@@ -10,7 +10,7 @@ http://www.econ.yale.edu/~shiller/data.htm
 import pandas as pd
 
 
-def hf_sp_500(year="2017"):
+def hf_sp_500(year: str = "2017") -> pd.DataFrame:
     """
     S&P 500 minute data from 2012-2018
     :param year: from 2012-2018
