@@ -1,18 +1,18 @@
 # -*- coding:utf-8 -*-
 # /usr/bin/env python
 """
-Date: 2020/12/28 16:31
+Date: 2021/7/6 20:31
 Desc: 股票基本信息
-# TODO xlrd 支持库后面需要移除
 """
 import json
+import warnings
 from io import BytesIO
 
 import pandas as pd
 import requests
 
 
-def stock_info_sz_name_code(indicator: str = "CDR列表") -> pd.DataFrame:
+def stock_info_sz_name_code(indicator: str = "A股列表") -> pd.DataFrame:
     """
     深圳证券交易所-股票列表
     http://www.szse.cn/market/product/stock/list/index.html
@@ -30,9 +30,45 @@ def stock_info_sz_name_code(indicator: str = "CDR列表") -> pd.DataFrame:
          "random": "0.6935816432433362",
     }
     r = requests.get(url, params=params)
-    temp_df = pd.read_excel(BytesIO(r.content), engine="xlrd")
+    with warnings.catch_warnings(record=True):
+        warnings.simplefilter("always")
+        temp_df = pd.read_excel(BytesIO(r.content))
     if len(temp_df) > 10:
-        temp_df["A股代码"] = temp_df["A股代码"].astype(str).str.zfill(6)
+        if indicator == "A股列表":
+            temp_df["A股代码"] = temp_df["A股代码"].astype(str).str.split('.', expand=True).iloc[:, 0].str.zfill(6).str.replace("000nan", "")
+            temp_df = temp_df[[
+                '板块',
+                'A股代码',
+                'A股简称',
+                'A股上市日期',
+                'A股总股本',
+                'A股流通股本',
+                '所属行业',
+            ]]
+        elif indicator == "B股列表":
+            temp_df["B股代码"] = temp_df["B股代码"].astype(str).str.split('.', expand=True).iloc[:, 0].str.zfill(6).str.replace("000nan", "")
+            temp_df = temp_df[[
+                '板块',
+                'B股代码',
+                'B股简称',
+                'B股上市日期',
+                'B股总股本',
+                'B股流通股本',
+                '所属行业',
+            ]]
+        elif indicator == "AB股列表":
+            temp_df["A股代码"] = temp_df["A股代码"].astype(str).str.split('.', expand=True).iloc[:, 0].str.zfill(6).str.replace("000nan", "")
+            temp_df["B股代码"] = temp_df["B股代码"].astype(str).str.split('.', expand=True).iloc[:, 0].str.zfill(6).str.replace("000nan", "")
+            temp_df = temp_df[[
+                '板块',
+                'A股代码',
+                'A股简称',
+                'A股上市日期',
+                'B股代码',
+                'B股简称',
+                'B股上市日期',
+                '所属行业',
+            ]]
         return temp_df
     else:
         return temp_df
@@ -132,9 +168,11 @@ def stock_info_sz_delist(indicator: str = "暂停上市公司") -> pd.DataFrame:
         "random": "0.6935816432433362",
     }
     r = requests.get(url, params=params)
-    temp_df = pd.read_excel(BytesIO(r.content), engine="xlrd")
-    temp_df["证券代码"] = temp_df["证券代码"].astype("str").str.zfill(6)
-    return temp_df
+    with warnings.catch_warnings(record=True):
+        warnings.simplefilter("always")
+        temp_df = pd.read_excel(BytesIO(r.content))
+        temp_df["证券代码"] = temp_df["证券代码"].astype("str").str.zfill(6)
+        return temp_df
 
 
 def stock_info_sz_change_name(indicator: str = "全称变更") -> pd.DataFrame:
@@ -155,9 +193,11 @@ def stock_info_sz_change_name(indicator: str = "全称变更") -> pd.DataFrame:
         "random": "0.6935816432433362",
     }
     r = requests.get(url, params=params)
-    temp_df = pd.read_excel(BytesIO(r.content), engine="xlrd")
-    temp_df["证券代码"] = temp_df["证券代码"].astype("str").str.zfill(6)
-    return temp_df
+    with warnings.catch_warnings(record=True):
+        warnings.simplefilter("always")
+        temp_df = pd.read_excel(BytesIO(r.content))
+        temp_df["证券代码"] = temp_df["证券代码"].astype("str").str.zfill(6)
+        return temp_df
 
 
 def stock_info_change_name(stock: str = "688588") -> pd.DataFrame:
