@@ -1,7 +1,7 @@
 # -*- coding:utf-8 -*-
 # /usr/bin/env python
 """
-Date: 2019/12/27 18:02
+Date: 2021/1/20 11:02
 Desc: 东方财富网-数据中心-特色数据-股权质押
 东方财富网-数据中心-特色数据-股权质押-股权质押市场概况: http://data.eastmoney.com/gpzy/marketProfile.aspx
 东方财富网-数据中心-特色数据-股权质押-上市公司质押比例: http://data.eastmoney.com/gpzy/pledgeRatio.aspx
@@ -10,72 +10,44 @@ Desc: 东方财富网-数据中心-特色数据-股权质押
 东方财富网-数据中心-特色数据-股权质押-质押机构分布统计-银行: http://data.eastmoney.com/gpzy/distributeStatistics.aspx
 东方财富网-数据中心-特色数据-股权质押-行业数据: http://data.eastmoney.com/gpzy/industryData.aspx
 """
-import requests
 import demjson
 import pandas as pd
-
-# pd.set_option('display.max_columns', 500)
-# pd.set_option('display.max_rows', 500)
+import requests
+from tqdm import tqdm
 
 
-def _get_page_num_gpzy_market_profile():
-    """
-    东方财富网-数据中心-特色数据-股权质押-股权质押市场概况
-    http://data.eastmoney.com/gpzy/marketProfile.aspx
-    :return: int 获取 股权质押市场概况 的总页数
-    """
-    url = "http://dcfm.eastmoney.com/EM_MutiSvcExpandInterface/api/js/get"
-    params = {
-        "type": "ZD_SUM",
-        "token": "70f12f2f4f091e459a279469fe49eca5",
-        "cmd": "",
-        "st": "tdate",
-        "sr": "-1",
-        "p": "3",
-        "ps": "5000",
-        "js": "var zvxnZOnT={pages:(tp),data:(x),font:(font)}",
-        "rt": "52583914",
-    }
-    res = requests.get(url, params=params)
-    data_json = demjson.decode(res.text[res.text.find("={") + 1 :])
-    return data_json["pages"]
-
-
-def stock_em_gpzy_profile():
+def stock_em_gpzy_profile() -> pd.DataFrame:
     """
     东方财富网-数据中心-特色数据-股权质押-股权质押市场概况
     http://data.eastmoney.com/gpzy/marketProfile.aspx
     :return: pandas.DataFrame
     """
     url = "http://dcfm.eastmoney.com/EM_MutiSvcExpandInterface/api/js/get"
-    page_num = _get_page_num_gpzy_market_profile()
     temp_df = pd.DataFrame()
-    for page in range(1, page_num + 1):
-        print(f"一共{page_num}页, 正在下载第{page}页")
-        params = {
-            "type": "ZD_SUM",
-            "token": "70f12f2f4f091e459a279469fe49eca5",
-            "cmd": "",
-            "st": "tdate",
-            "sr": "-1",
-            "p": str(page),
-            "ps": "5000",
-            "js": "var zvxnZOnT={pages:(tp),data:(x),font:(font)}",
-            "rt": "52583914",
-        }
-        res = requests.get(url, params=params)
-        data_text = res.text
-        data_json = demjson.decode(data_text[data_text.find("={") + 1 :])
-        map_dict = dict(
-            zip(
-                pd.DataFrame(data_json["font"]["FontMapping"])["code"],
-                pd.DataFrame(data_json["font"]["FontMapping"])["value"],
-            )
+    params = {
+        "type": "ZD_SUM",
+        "token": "70f12f2f4f091e459a279469fe49eca5",
+        "cmd": "",
+        "st": "tdate",
+        "sr": "-1",
+        "p": "1",
+        "ps": "5000",
+        "js": "var zvxnZOnT={pages:(tp),data:(x),font:(font)}",
+        "rt": "52583914",
+    }
+    res = requests.get(url, params=params)
+    data_text = res.text
+    data_json = demjson.decode(data_text[data_text.find("={") + 1 :])
+    map_dict = dict(
+        zip(
+            pd.DataFrame(data_json["font"]["FontMapping"])["code"],
+            pd.DataFrame(data_json["font"]["FontMapping"])["value"],
         )
-        for key, value in map_dict.items():
-            data_text = data_text.replace(key, str(value))
-        data_json = demjson.decode(data_text[data_text.find("={") + 1 :])
-        temp_df = temp_df.append(pd.DataFrame(data_json["data"]), ignore_index=True)
+    )
+    for key, value in map_dict.items():
+        data_text = data_text.replace(key, str(value))
+    data_json = demjson.decode(data_text[data_text.find("={") + 1 :])
+    temp_df = temp_df.append(pd.DataFrame(data_json["data"]), ignore_index=True)
     temp_df.columns = [
         "交易日期",
         "sc_zsz",
@@ -105,34 +77,7 @@ def stock_em_gpzy_profile():
     return temp_df
 
 
-def _get_page_num_gpzy_market_pledge_ratio(trade_date="2020-08-19"):
-    """
-    东方财富网-数据中心-特色数据-股权质押-上市公司质押比例
-    http://data.eastmoney.com/gpzy/pledgeRatio.aspx
-    :param trade_date: 指定交易日, 访问 http://data.eastmoney.com/gpzy/pledgeRatio.aspx 查询
-    :type trade_date: str
-    :return: 上市公司质押比例的总页数
-    :rtype: int
-    """
-    url = "http://dcfm.eastmoney.com/EM_MutiSvcExpandInterface/api/js/get"
-    params = {
-        "type": "ZD_QL_LB",
-        "token": "70f12f2f4f091e459a279469fe49eca5",
-        "cmd": "",
-        "st": "amtshareratio",
-        "sr": "-1",
-        "p": "2",
-        "ps": "5000",
-        "js": "var rlJqyOhv={pages:(tp),data:(x),font:(font)}",
-        "filter": f"(tdate='{trade_date}')",
-        "rt": "52584436",
-    }
-    res = requests.get(url, params=params)
-    data_json = demjson.decode(res.text[res.text.find("={") + 1 :])
-    return data_json["pages"]
-
-
-def stock_em_gpzy_pledge_ratio(trade_date="2020-08-07"):
+def stock_em_gpzy_pledge_ratio(trade_date: str = "2020-08-07") -> pd.DataFrame:
     """
     东方财富网-数据中心-特色数据-股权质押-上市公司质押比例
     http://data.eastmoney.com/gpzy/pledgeRatio.aspx
@@ -142,35 +87,32 @@ def stock_em_gpzy_pledge_ratio(trade_date="2020-08-07"):
     :rtype: pandas.DataFrame
     """
     url = "http://dcfm.eastmoney.com/EM_MutiSvcExpandInterface/api/js/get"
-    page_num = _get_page_num_gpzy_market_pledge_ratio(trade_date)
     temp_df = pd.DataFrame()
-    for page in range(1, page_num + 1):
-        print(f"一共{page_num}页, 正在下载第{page}页")
-        params = {
-            "type": "ZD_QL_LB",
-            "token": "70f12f2f4f091e459a279469fe49eca5",
-            "cmd": "",
-            "st": "amtshareratio",
-            "sr": "-1",
-            "p": str(page),
-            "ps": "5000",
-            "js": "var rlJqyOhv={pages:(tp),data:(x),font:(font)}",
-            "filter": f"(tdate='{trade_date}')",
-            "rt": "52584436",
-        }
-        res = requests.get(url, params=params)
-        data_text = res.text
-        data_json = demjson.decode(data_text[data_text.find("={") + 1 :])
-        map_dict = dict(
-            zip(
-                pd.DataFrame(data_json["font"]["FontMapping"])["code"],
-                pd.DataFrame(data_json["font"]["FontMapping"])["value"],
-            )
+    params = {
+        "type": "ZD_QL_LB",
+        "token": "70f12f2f4f091e459a279469fe49eca5",
+        "cmd": "",
+        "st": "amtshareratio",
+        "sr": "-1",
+        "p": "1",
+        "ps": "5000",
+        "js": "var rlJqyOhv={pages:(tp),data:(x),font:(font)}",
+        "filter": f"(tdate='{trade_date}')",
+        "rt": "52584436",
+    }
+    res = requests.get(url, params=params)
+    data_text = res.text
+    data_json = demjson.decode(data_text[data_text.find("={") + 1 :])
+    map_dict = dict(
+        zip(
+            pd.DataFrame(data_json["font"]["FontMapping"])["code"],
+            pd.DataFrame(data_json["font"]["FontMapping"])["value"],
         )
-        for key, value in map_dict.items():
-            data_text = data_text.replace(key, str(value))
-        data_json = demjson.decode(data_text[data_text.find("={") + 1 :])
-        temp_df = temp_df.append(pd.DataFrame(data_json["data"]), ignore_index=True)
+    )
+    for key, value in map_dict.items():
+        data_text = data_text.replace(key, str(value))
+    data_json = demjson.decode(data_text[data_text.find("={") + 1 :])
+    temp_df = temp_df.append(pd.DataFrame(data_json["data"]), ignore_index=True)
     temp_df.columns = [
         "股票代码",
         "股票简称",
@@ -204,7 +146,7 @@ def stock_em_gpzy_pledge_ratio(trade_date="2020-08-07"):
     return temp_df
 
 
-def _get_page_num_gpzy_market_pledge_ratio_detail():
+def _get_page_num_gpzy_market_pledge_ratio_detail() -> int:
     """
     东方财富网-数据中心-特色数据-股权质押-重要股东股权质押明细
     http://data.eastmoney.com/gpzy/pledgeDetail.aspx
@@ -217,7 +159,7 @@ def _get_page_num_gpzy_market_pledge_ratio_detail():
         "cmd": "",
         "st": "ndate",
         "sr": "-1",
-        "p": "2",
+        "p": "1",
         "ps": "5000",
         "js": "var oiIxTSgC={pages:(tp),data:(x),font:(font)}",
         "filter": "(datatype=1)",
@@ -228,7 +170,7 @@ def _get_page_num_gpzy_market_pledge_ratio_detail():
     return data_json["pages"]
 
 
-def stock_em_gpzy_pledge_ratio_detail():
+def stock_em_gpzy_pledge_ratio_detail() -> pd.DataFrame:
     """
     东方财富网-数据中心-特色数据-股权质押-重要股东股权质押明细
     http://data.eastmoney.com/gpzy/pledgeDetail.aspx
@@ -237,8 +179,7 @@ def stock_em_gpzy_pledge_ratio_detail():
     url = "http://dcfm.eastmoney.com/EM_MutiSvcExpandInterface/api/js/get"
     page_num = _get_page_num_gpzy_market_pledge_ratio_detail()
     temp_df = pd.DataFrame()
-    for page in range(1, page_num + 1):
-        print(f"一共{page_num}页, 正在下载第{page}页")
+    for page in tqdm(range(1, page_num + 1)):
         params = {
             "type": "GDZY_LB",
             "token": "70f12f2f4f091e459a279469fe49eca5",
@@ -251,8 +192,8 @@ def stock_em_gpzy_pledge_ratio_detail():
             "filter": "(datatype=1)",
             "rt": "52584576",
         }
-        res = requests.get(url, params=params)
-        data_text = res.text
+        r = requests.get(url, params=params)
+        data_text = r.text
         data_json = demjson.decode(data_text[data_text.find("={") + 1 :])
         map_dict = dict(
             zip(
@@ -336,7 +277,7 @@ def stock_em_gpzy_pledge_ratio_detail():
     return temp_df
 
 
-def _get_page_num_gpzy_distribute_statistics_company():
+def _get_page_num_gpzy_distribute_statistics_company() -> int:
     """
     东方财富网-数据中心-特色数据-股权质押-质押机构分布统计-证券公司
     http://data.eastmoney.com/gpzy/distributeStatistics.aspx
@@ -360,7 +301,7 @@ def _get_page_num_gpzy_distribute_statistics_company():
     return data_json["pages"]
 
 
-def stock_em_gpzy_distribute_statistics_company():
+def stock_em_gpzy_distribute_statistics_company() -> pd.DataFrame:
     """
     东方财富网-数据中心-特色数据-股权质押-质押机构分布统计-证券公司
     http://data.eastmoney.com/gpzy/distributeStatistics.aspx
@@ -369,8 +310,7 @@ def stock_em_gpzy_distribute_statistics_company():
     url = "http://dcfm.eastmoney.com/EM_MutiSvcExpandInterface/api/js/get"
     page_num = _get_page_num_gpzy_distribute_statistics_company()
     temp_df = pd.DataFrame()
-    for page in range(1, page_num + 1):
-        print(f"一共{page_num}页, 正在下载第{page}页")
+    for page in tqdm(range(1, page_num + 1)):
         params = {
             "type": "GDZY_ZYJG_SUM",
             "token": "70f12f2f4f091e459a279469fe49eca5",
@@ -426,7 +366,7 @@ def stock_em_gpzy_distribute_statistics_company():
     return temp_df
 
 
-def _get_page_num_gpzy_distribute_statistics_bank():
+def _get_page_num_gpzy_distribute_statistics_bank() -> int:
     """
     东方财富网-数据中心-特色数据-股权质押-质押机构分布统计-银行
     http://data.eastmoney.com/gpzy/distributeStatistics.aspx
@@ -450,7 +390,7 @@ def _get_page_num_gpzy_distribute_statistics_bank():
     return data_json["pages"]
 
 
-def stock_em_gpzy_distribute_statistics_bank():
+def stock_em_gpzy_distribute_statistics_bank() -> pd.DataFrame:
     """
     东方财富网-数据中心-特色数据-股权质押-质押机构分布统计-银行
     http://data.eastmoney.com/gpzy/distributeStatistics.aspx
@@ -516,7 +456,7 @@ def stock_em_gpzy_distribute_statistics_bank():
     return temp_df
 
 
-def _get_page_num_gpzy_industry_data():
+def _get_page_num_gpzy_industry_data() -> int:
     """
     东方财富网-数据中心-特色数据-股权质押-上市公司质押比例-行业数据
     http://data.eastmoney.com/gpzy/industryData.aspx
@@ -539,7 +479,7 @@ def _get_page_num_gpzy_industry_data():
     return data_json["pages"]
 
 
-def stock_em_gpzy_industry_data():
+def stock_em_gpzy_industry_data() -> pd.DataFrame:
     """
     东方财富网-数据中心-特色数据-股权质押-上市公司质押比例-行业数据
     http://data.eastmoney.com/gpzy/industryData.aspx
@@ -593,16 +533,20 @@ if __name__ == "__main__":
     stock_em_gpzy_profile_df = stock_em_gpzy_profile()
     print(stock_em_gpzy_profile_df)
 
-    stock_em_gpzy_pledge_ratio_df = stock_em_gpzy_pledge_ratio(trade_date="2020-08-07")
+    stock_em_gpzy_pledge_ratio_df = stock_em_gpzy_pledge_ratio(trade_date="2021-04-30")
     print(stock_em_gpzy_pledge_ratio_df)
 
     stock_em_gpzy_pledge_ratio_detail_df = stock_em_gpzy_pledge_ratio_detail()
     print(stock_em_gpzy_pledge_ratio_detail_df)
 
-    stock_em_gpzy_distribute_statistics_company_df = stock_em_gpzy_distribute_statistics_company()
+    stock_em_gpzy_distribute_statistics_company_df = (
+        stock_em_gpzy_distribute_statistics_company()
+    )
     print(stock_em_gpzy_distribute_statistics_company_df)
 
-    stock_em_gpzy_distribute_statistics_bank_df = stock_em_gpzy_distribute_statistics_bank()
+    stock_em_gpzy_distribute_statistics_bank_df = (
+        stock_em_gpzy_distribute_statistics_bank()
+    )
     print(stock_em_gpzy_distribute_statistics_bank_df)
 
     stock_em_gpzy_industry_data_df = stock_em_gpzy_industry_data()
